--- loncom/publisher/lonpubdir.pm 2011/12/23 17:21:18 1.140
+++ loncom/publisher/lonpubdir.pm 2014/03/11 01:16:49 1.150
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# Construction Space Directory Lister
#
-# $Id: lonpubdir.pm,v 1.140 2011/12/23 17:21:18 www Exp $
+# $Id: lonpubdir.pm,v 1.150 2014/03/11 01:16:49 musolffc Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -33,7 +33,6 @@ use strict;
use Apache::File;
use File::Copy;
use Apache::Constants qw(:common :http :methods);
-use Apache::loncacc;
use Apache::loncommon();
use Apache::lonhtmlcommon();
use Apache::londiff();
@@ -47,12 +46,12 @@ sub handler {
my $r=shift;
- # Validate access to the construction space and get username@domain.
+ # Validate access to the construction space and get username:domain.
my $uname;
my $udom;
- ($uname,$udom)=&Apache::loncacc::constructaccess($r->uri);
+ ($uname,$udom)=&Apache::lonnet::constructaccess($r->uri);
unless (($uname) && ($udom)) {
return HTTP_NOT_ACCEPTABLE;
}
@@ -80,15 +79,23 @@ sub handler {
my $numdir = 0;
my $numres = 0;
+ # Retrieving value for sortby from QUERY_STRING
+ &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['sortby']);
+
+ # Default sort by 'Name'
+ if (! exists($env{'form.sortby'})) {
+ $env{'form.sortby'} = 'filename';
+ }
+
# Start off the directory table.
$r->print(&Apache::loncommon::start_data_table()
.&Apache::loncommon::start_data_table_header_row()
.'
'.&mt('Type').' | '
.''.&mt('Actions').' | '
- .''.&mt('Name').' | '
+ .'Name ▼ | '
.''.&mt('Title').' | '
.''.&mt('Status').' | '
- .''.&mt('Last Modified').' | '
+ .'Last Modified ▼ | '
.&Apache::loncommon::end_data_table_header_row()
);
@@ -96,24 +103,51 @@ sub handler {
my $dirptr=16384; # Mask indicating a directory in stat.cmode.
opendir(DIR,$fn);
+ my $filehash = {};
+ my $sortby = $env{'form.sortby'};
my @files=sort {uc($a) cmp uc($b)} (readdir(DIR));
foreach my $filename (@files) {
- my ($cdev,$cino,$cmode,$cnlink,
- $cuid,$cgid,$crdev,$csize,
- $catime,$cmtime,$cctime,
- $cblksize,$cblocks)=stat($fn.'/'.$filename);
-
- my $extension='';
- if ($filename=~/\.(\w+)$/) { $extension=$1; }
- if ($cmode&$dirptr) {
- &putdirectory($r, $thisdisfn, $linkdir, $filename, $cmtime,$targetdir,\%bombs,\$numdir);
- } elsif (&Apache::loncommon::fileembstyle($extension) ne 'hdn') {
- &putresource($r, $udom, $uname, $filename, $thisdisfn, $resdir,
- $targetdir, $linkdir, $cmtime,\%bombs,\$numres);
- } else {
- # "hidden" extension and not a directory, so hide it away.
+ next if ($filename eq '.DS_Store');
+ my ($cmode,$cmtime)=(stat($fn.'/'.$filename))[2,9];
+ # If you want to sort by "last modified", we need to make this hash.
+ if ($sortby eq 'cmtime') {
+ $filehash->{ $filename } = {"cmtime" => $cmtime,};
}
- }
+ # Otherwise sort by name. Don't bother with filehash. Continue printing contents.
+ else {
+ my $extension='';
+ if ($filename=~/\.(\w+)$/) { $extension=$1; }
+ if ($cmode&$dirptr) {
+ &putdirectory($r, $thisdisfn, $linkdir, $filename, $cmtime,$targetdir,\%bombs,\$numdir);
+ } elsif (&Apache::loncommon::fileembstyle($extension) ne 'hdn') {
+ &putresource($r, $udom, $uname, $filename, $thisdisfn, $resdir,
+ $targetdir, $linkdir, $cmtime,\%bombs,\$numres);
+ } else {
+ # "hidden" extension and not a directory, so hide it away.
+ }
+ }
+ };
+
+ # Sorting files by "last modified" if that's what you selected
+ if ($sortby eq 'cmtime') {
+ my @sorted_files = sort {
+ $filehash->{$b}->{$sortby} <=> $filehash->{$a}->{$sortby}
+ } (keys(%{$filehash}));
+ foreach my $filename (@sorted_files) {
+ my ($cmode,$cmtime)=(stat($fn.'/'.$filename))[2,9];
+ my $extension='';
+ if ($filename=~/\.(\w+)$/) { $extension=$1; }
+ if ($cmode&$dirptr) {
+ &putdirectory($r, $thisdisfn, $linkdir, $filename, $cmtime,$targetdir,\%bombs,\$numdir);
+ } elsif (&Apache::loncommon::fileembstyle($extension) ne 'hdn') {
+ &putresource($r, $udom, $uname, $filename, $thisdisfn, $resdir,
+ $targetdir, $linkdir, $cmtime,\%bombs,\$numres);
+ } else {
+ # "hidden" extension and not a directory, so hide it away.
+ };
+ };
+ };
+
closedir(DIR);
$r->print(&Apache::loncommon::end_data_table()
@@ -144,20 +178,28 @@ sub startpage {
&Apache::lonhtmlcommon::clear_breadcrumbs();
&Apache::lonhtmlcommon::add_breadcrumb({
- 'text' => 'Construction Space',
+ 'text' => 'Authoring Space',
'href' => &Apache::loncommon::authorspace($formaction),
});
# breadcrumbs (and tools) will be created
# in start_page->bodytag->innerregister
$env{'request.noversionuri'}=$formaction;
- $r->print(&Apache::loncommon::start_page('Construction Space',undef));
+ $r->print(&Apache::loncommon::start_page('Authoring Space',undef));
+
+ my $londocroot = $Apache::lonnet::perlvar{'lonDocRoot'};
+ my $current_disk_usage = &Apache::lonnet::diskusage($udom,$uname,"$londocroot/priv/$udom/$uname");
+ my $disk_quota = &Apache::loncommon::get_user_quota($uname,$udom,'author'); #expressed in Mb
+ $disk_quota = 1000 * $disk_quota; # convert from Mb to kb
$r->print(&Apache::loncommon::head_subbox(
- &Apache::loncommon::CSTR_pageheader()));
+ ''
+ .&Apache::lonhtmlcommon::display_usage($current_disk_usage,$disk_quota)
+ .'
'
+ .&Apache::loncommon::CSTR_pageheader()));
my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
- my $doctitle = 'LON-CAPA '.&mt('Construction Space');
+ my $doctitle = 'LON-CAPA '.&mt('Authoring Space');
my $newname = &mt('New Name');
my $pubdirscript=(<
@@ -458,11 +500,12 @@ sub putdirectory {
my $disfilename = $dirname;
# Don't display directory itself, and there is no way up from root directory
unless ((($dirname eq '..') && ($reqfile=~/^\/[^\/]+\/[^\/]+$/)) || ($dirname eq '.')) {
- my $kaputt=0;
+ my $kaputt=0;
if (ref($bombs) eq 'HASH') {
- foreach my $key (keys(%{$bombs})) {
- if ($key =~ m{^\Q$targetdir/$disfilename\E/}) { $kaputt=1; last; }
- }
+ foreach my $key (keys(%{$bombs})) {
+ my $currentdir = &Apache::lonnet::declutter("$targetdir/$disfilename");
+ if (($key) =~ m{^\Q$currentdir\E/}) { $kaputt=1; last; }
+ }
}
#
# Get the metadata from that directory's default.meta to display titles
@@ -522,9 +565,9 @@ sub putresource {
my $pubstatus = 'unpublished';
my $status=&mt('Unpublished');
my $css_class='LC_browser_file';
- my $title=' ';
+ my $title='';
my $publish_button=&mt('Publish');
- my $cstr_dir = $r->dir_config('lonDocRoot').'/priv/'.$udom.'/'.$uname.'/'.$thisdisfn.'/';
+ my $cstr_dir = $r->dir_config('lonDocRoot').'/priv'.$thisdisfn;
my $linkfilename=&HTML::Entities::encode('/priv'.$thisdisfn.'/'.$filename,'<>&"');
if (-e $resdir.'/'.$filename) {
@@ -590,15 +633,11 @@ sub putresource {
&mt('Diffs'),600,500);
}
}
-
- $title.="\n".'
'.
- ($$bombs{$targetdir.'/'.$filename}?'':&mt('Edit Metadata')).'';
-
if (!$meta_same) {
$title = &mt('Metadata Modified').'
'.$title.
'
'.
&Apache::loncommon::modal_link(
- '/adm/diff?filename=/priv/'.$linkfilename.'.meta'.'&versiontwo=priv',
+ '/adm/diff?filename='.$linkfilename.'.meta'.'&versiontwo=priv',
&mt('Metadata Diffs'),600,500);
$title.="\n".'
'.
&Apache::loncommon::modal_link(
@@ -609,14 +648,22 @@ sub putresource {
&Apache::loncommon::modal_link(
'/adm/retrieve?filename='.$linkfilename.'&inhibitmenu=yes&add_modal=yes',&mt('Retrieve'),600,500);
}
+ # Allow editing metadata of published and unpublished resources
+ $title .= "\n".'
' if ($title);
+ $title .= ''.
+ ($$bombs{&Apache::lonnet::declutter($targetdir.'/'.$filename)}?
+ '':
+ &mt('Edit Metadata')).
+ '';
+
my $editlink='';
my $editlink2='';
if ($filename=~/\.(xml|html|htm|xhtml|xhtm|sty)$/) {
- $editlink='
('.&mt('Edit').')';
+ $editlink='
('.&mt('Edit').')';
}
if ($filename=~/$LONCAPA::assess_re/) {
- $editlink=' ('.&mt('EditXML').')';
- $editlink2='
('.&mt('Edit').')';
+ $editlink=' ('.&mt('EditXML').')';
+ $editlink2='
('.&mt('Edit').')';
}
if ($filename=~/\.(problem|exam|quiz|assess|survey|form|library|xml|html|htm|xhtml|xhtm|sty)$/) {
$editlink.=' ('.&mt('Clean Up').')';
@@ -702,7 +749,7 @@ __END__
=head1 NAME
-Apache::lonpubdir - Construction space directory lister
+Apache::lonpubdir - Authoring space directory lister
=head1 SYNOPSIS
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
-# Construction Space Directory Lister
+# Authoring Space Directory Lister
#